/*
 * FolderViewPanel.java
 *
 * Copyright (C) 2007 Takis Diakoumis
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */

package org.underworldlabs.jobexftp;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.Point;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.swing.BorderFactory;
import javax.swing.ImageIcon;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.border.Border;
import javax.swing.border.EmptyBorder;
import javax.swing.table.AbstractTableModel;
import javax.swing.table.DefaultTableCellRenderer;
import javax.swing.table.TableColumnModel;
import org.underworldlabs.jobexftp.obexobjects.ObexFile;
import org.underworldlabs.jobexftp.obexobjects.ObexFolder;
import org.underworldlabs.jobexftp.obexobjects.ObexObject;
import org.underworldlabs.jobexftp.util.GUIUtilities;
import org.underworldlabs.swing.actions.ActionBuilder;
import org.underworldlabs.swing.table.DefaultTableHeaderRenderer;

/**
 * Right-hand panel for folder selection contents viewing. 
 *
 * @author Takis Diakoumis
 */
public class FolderViewPanel extends JPanel 
                             implements MouseListener {
    
    /** the folder contents table view */
    private JTable table;

    /** the table model */
    private FolderContentsTableModel model;
    
    /** Creates a new instance of FolderViewPanel */
    public FolderViewPanel() {
        super(new BorderLayout());
        try {
            init();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
    
    private void init() throws Exception {
        model = new FolderContentsTableModel();
        table = new JTable(model);
        table.setRowHeight(22);
        table.setColumnSelectionAllowed(false);
        table.getTableHeader().setReorderingAllowed(false);
        table.getTableHeader().setDefaultRenderer(new DefaultTableHeaderRenderer());
        //table.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);

        table.setShowGrid(false);
        table.setIntercellSpacing(new Dimension(0, 0));
        
        TableColumnModel tcm = table.getColumnModel();
        tcm.getColumn(0).setPreferredWidth(300);
        tcm.getColumn(1).setPreferredWidth(100);
        tcm.getColumn(2).setPreferredWidth(100);

        tcm.getColumn(0).setCellRenderer(new ObjectNameRenderer());
        tcm.getColumn(1).setCellRenderer(new ObexPropertyRenderer());
        tcm.getColumn(2).setCellRenderer(new ObexPropertyRenderer());
        
        table.addMouseListener(this);
        
        JScrollPane scroller = new JScrollPane(table);
        scroller.getViewport().setBackground(Color.WHITE);
        
        add(scroller, BorderLayout.CENTER);
        //setBorder(BorderFactory.createEmptyBorder(2,2,2,2));
        setPreferredSize(new Dimension(500, 270));
    }
 
    public void setFolderDisplay(List<ObexObject> values) {
        model.setValues(values);
    }
    
    private ObexObject getObexObjectAt(Point point) {
        int row = table.rowAtPoint(point);
        if (row == -1) {
            return null;
        }
        return model.getObexObjectAt(row);
    }

    public List<ObexObject> getSelectedObjects() {
        int[] rows = table.getSelectedRows();
        if (rows != null && rows.length > 0) {
            List<ObexObject> objects = null;
            for (int i = 0; i < rows.length; i++) {
                ObexObject object = model.getObexObjectAt(rows[i]);
                if (object != null) {
                    
                    if (objects == null) {
                        objects = new ArrayList<ObexObject>();
                    }
                    objects.add(object);

                }
            }
            return objects;
        }
        return new ArrayList<ObexObject>(0);
    }

    public List<ObexFile> getSelectedFiles() {
        int[] rows = table.getSelectedRows();
        if (rows != null && rows.length > 0) {
            List<ObexFile> files = null;
            for (int i = 0; i < rows.length; i++) {
                ObexObject object = model.getObexObjectAt(rows[i]);
                if (object != null && object instanceof ObexFile) {

                    if (files == null) {
                        files = new ArrayList<ObexFile>();
                    }
                    files.add((ObexFile)object);

                }
            }
            return files;
        }
        return new ArrayList<ObexFile>(0);
    }

    public String[] getSelectedFolders() {
        int[] rows = table.getSelectedRows();
        if (rows != null && rows.length > 0) {
            String[] folders = new String[rows.length];
            for (int i = 0; i < folders.length; i++) {
                ObexObject object = model.getObexObjectAt(rows[i]);
                if (object != null && object instanceof ObexFolder) {

                    if (folders == null) {
                        folders = new String[rows.length];
                    }
                    folders[i] = object.getPath();

                }
            }
            return folders;
        }
        return new String[0];
    }

    // ----------------------------------
    // MouseListener implementation
    // ----------------------------------
    
    public void mouseClicked(MouseEvent e) {
        // only interested in double clicks
        if (e.getClickCount() < 2) {
            return;
        } 

        // locate the obex object and expand the path
        Point point = new Point(e.getX(), e.getY());
        ObexObject obexObject = getObexObjectAt(point);
        if (obexObject == null) {
            return;
        }
        
        if (obexObject instanceof ObexFolder) {
            JObexController.selectedNodeExpanded(obexObject.getName());
        }
        else if (obexObject instanceof ObexFile) {
            if (JObexController.isImageFile(obexObject.getName())) {
                ActionBuilder.get("view-file-command").actionPerformed(null);
            }
        }
        
        
    }

    public void mousePressed(MouseEvent e) {
        maybeShowPopup(e);
    }

    public void mouseReleased(MouseEvent e) {
        maybeShowPopup(e);
    }

    private void maybeShowPopup(MouseEvent e) {
        
      /*
        if (e.isPopupTrigger()) {
            Point point = new Point(e.getX(), e.getY());            
            // get the connection at this point
            ObexObject obexObject = getObexObjectAt(point);
            if (obexObject != null) {
                
            
            if (databaseConnection != null) {
                if (popupMenu == null) {
                    popupMenu = new PopMenu();
                }
                // remove the current row selection
                table.clearSelection();
                
                // set the popup row as selected
                int row = model.indexOf(databaseConnection);
                table.addRowSelectionInterval(row, row);
                
                // enable/disable items
                popupMenu.setToConnect(!databaseConnection.isConnected());
                popupMenu.show(e.getComponent(), point.x, point.y);
            }
        }
        */
    }

    public void mouseEntered(MouseEvent e) {}
    public void mouseExited(MouseEvent e) {}

    // --------------------------------------------------
    

    class FolderContentsTableModel extends AbstractTableModel {
        
        private List<ObexObject> values;
        private String[] header = {"Name", "Type", "Size"};
        private DecimalFormat df = new DecimalFormat("0.00");

        public FolderContentsTableModel() {}
        
        public void setValues(List<ObexObject> values) {
            this.values = values;
            fireTableDataChanged();
        }

        public ObexObject getObexObjectAt(int row) {
            if (row >= -1) {
                return values.get(row);
            }
            return null;
        }
        
        public int getRowCount() {
            if (values == null) {
                return 0;
            }
            return values.size();
        }
        
        public int getColumnCount() {
            return header.length;
        }
        
        public String getColumnName(int col) {
            return header[col];
        }

        public Object getValueAt(int row, int col) {
            ObexObject obexObject = values.get(row);
            if (obexObject instanceof ObexFile) {
                ObexFile obexFile = (ObexFile)obexObject;
                switch (col) {
                    case 0:
                        return obexFile.getName();
                    case 1:
                        String name = obexFile.getName();
                        int dotIndex = name.lastIndexOf('.');
                        if (dotIndex != -1) {
                            return name.substring(dotIndex + 1).toUpperCase() +
                                    " File";
                        } else {
                            return "";
                        }
                    case 2:
                        double size = (double)obexFile.getSize() / 1000;
                        return df.format(size) + " KB ";
                }
                return obexFile;
            }
            else { // must be a folder object
                ObexFolder obexFolder = (ObexFolder)obexObject;
                switch (col) {
                    case 0:
                        return obexFolder.getName();
                    case 1:
                        return "Folder";
                }
                return "";
            }
        }
        
        public boolean isCellEditable() {
            return false;
        }

    }
    
    class ObjectNameRenderer extends DefaultTableCellRenderer {
        
        /** file/folder icons */
        private Map<String,ImageIcon> icons;
        
        /** folder icon file name */
        private String FOLDER_ICON = "Folder16.png";
        
        /** image icon file name */
        private String IMAGE_ICON = "Image16.gif";
        
        /** image icon file name */
        private String UNKNOWN_ICON = "Unknown16.gif";
        
        public ObjectNameRenderer() {
            setBorder(BorderFactory.createEmptyBorder(1, 10, 1, 0));

            // cache the icons
            String[] iconFiles = {FOLDER_ICON, IMAGE_ICON, UNKNOWN_ICON};
            icons = new HashMap<String,ImageIcon>(iconFiles.length);
            
            for (int i = 0; i < iconFiles.length; i++) {
                String name = iconFiles[i];
                icons.put(name, GUIUtilities.loadIcon(name));
            }

        }
        
        public Component getTableCellRendererComponent(JTable table,
                                                       Object value, 
                                                       boolean isSelected, 
                                                       boolean hasFocus,
                                                       int row, 
                                                       int column) {

            ObexObject obexObject = model.getObexObjectAt(row);
            String name = obexObject.getName();

            if (obexObject instanceof ObexFolder) {
                setIcon(icons.get(FOLDER_ICON));
            }
            else {
                ObexFile obexFile = (ObexFile)obexObject;
                if (JObexController.isImageFile(name)) {
                    setIcon(icons.get(IMAGE_ICON));
                }
                else {
                    setIcon(icons.get(UNKNOWN_ICON));
                }

            }

            setText(name);
            setIconTextGap(20);
            setFont(table.getFont());
            
            if (isSelected) {
                setBackground(table.getSelectionBackground());
                setForeground(table.getSelectionForeground());
            }	else {
                setBackground(table.getBackground());
                setForeground(table.getForeground());
            }

            return this;
        }
        
    }
    
    
    class ObexPropertyRenderer extends DefaultTableCellRenderer {
       
        private Border EMPTY_BORDER = new EmptyBorder(1, 2, 1, 0); 
        
        public ObexPropertyRenderer() {}
        
        public Component getTableCellRendererComponent(JTable table,
                                                       Object value, 
                                                       boolean isSelected, 
                                                       boolean hasFocus,
                                                       int row, 
                                                       int column) {

            if (value != null) {
                setText(value.toString());
            }

            if (column == 2) {
                setHorizontalAlignment(JLabel.RIGHT);
            }
            
            setFont(table.getFont());
            
            if (isSelected) {
                setBackground(table.getSelectionBackground());
                setForeground(table.getSelectionForeground());
            }	else {
                setBackground(table.getBackground());
                setForeground(table.getForeground());
            }

            setBorder(EMPTY_BORDER);
            
            return this;
        }

    }

}



