/*
 * JObexBasePanel.java
 *
 * Copyright (C) 2007 Takis Diakoumis
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */

package org.underworldlabs.jobexftp;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.util.List;
import javax.swing.BorderFactory;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JSplitPane;
import org.underworldlabs.jobexftp.obexobjects.ObexFile;
import org.underworldlabs.jobexftp.obexobjects.ObexObject;
import org.underworldlabs.jobexftp.util.GUIUtilities;
import org.underworldlabs.swing.FlatSplitPane;

/**
 *
 * @author takisd
 */
public class JObexBasePanel extends JPanel {

    /** the folder tree panel */
    private FolderTreePanel treePanel;
    
    /** the folder view table panel */
    private FolderViewPanel viewPanel;

    /** Creates a new instance of JObexBasePanel */
    public JObexBasePanel() {
        super(new BorderLayout());
        try {
            init();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
    
    private void init() throws Exception {    
        treePanel = new FolderTreePanel();
        viewPanel = new FolderViewPanel();
        
        JScrollPane logScroller = new JScrollPane(GUIUtilities.getLogPane());
        logScroller.setPreferredSize(new Dimension(viewPanel.getWidth(), 200));

        FlatSplitPane centerSplit = new FlatSplitPane(JSplitPane.VERTICAL_SPLIT);
        centerSplit.setDividerSize(4);
        centerSplit.setTopComponent(viewPanel);
        centerSplit.setBottomComponent(logScroller);
        centerSplit.setDividerLocation(0.75);
        centerSplit.setResizeWeight(0.75);

        FlatSplitPane mainSplit = new FlatSplitPane(JSplitPane.HORIZONTAL_SPLIT);
        mainSplit.setDividerSize(4);
        mainSplit.setLeftComponent(treePanel);
        mainSplit.setRightComponent(centerSplit);

        setBorder(BorderFactory.createEmptyBorder(0,2,1,2));
        
        add(mainSplit, BorderLayout.CENTER);
        setPreferredSize(new Dimension(800, 400));        
    }

    /**
     * Returns the current folder selection path.
     */
    protected String getSelectedFolder() {
        return treePanel.getSelectedFolder();
    }

    /**
     * Returns the selected objects (file and/or folders)
     * within the table view.
     */
    protected List<ObexObject> getSelectedObjects() {
        return viewPanel.getSelectedObjects();
    }
    
    /**
     * Returns the current file selection within the table view.
     */
    protected List<ObexFile> getSelectedFiles() {
        return viewPanel.getSelectedFiles();
    }

    /**
     * Fires to expand the selected tree row - if possible.
     */
    protected void selectedNodeExpanded(String name) {
        treePanel.selectedNodeExpanded(name);
    }

    /**
     * Indicates the currently selected path has been refreshed
     * and that it should be recreated with values from the 
     * specified list.
     */
    protected void reloadSelectedPath(List<ObexObject> list) {
        treePanel.selectedPathReloaded(list);
    }

    
    protected void folderSelected(List<ObexObject> list) {
        viewPanel.setFolderDisplay(list);
    }
    
    /**
     * Propagates the call that we are connected to the tree panel.
     */
    public void connected() {
        treePanel.connected();
    }
    
}



