/*
 * JObexFTP.java
 *
 * Copyright (C) 2007 Takis Diakoumis
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */

package org.underworldlabs.jobexftp;

import java.awt.BorderLayout;
import java.awt.Container;
import java.util.Properties;
import javax.swing.JComponent;
import javax.swing.JFrame;
import javax.swing.UIManager;
import javax.swing.UnsupportedLookAndFeelException;
import org.underworldlabs.jobexftp.util.GUIUtilities;
import org.underworldlabs.jobexftp.util.SystemResources;
import org.underworldlabs.swing.actions.ActionBuilder;
import org.underworldlabs.swing.util.IconUtilities;
import org.underworldlabs.util.SystemProperties;

/**
 *
 * @author Takis Diakoumis
 */
public class JObexFTP {
    
    /** the application frame */
    private static JFrame frame;
    
    /** Creates a new instance of JObexFTP */
    public JObexFTP() {
        
        // load the application properties
        SystemProperties.loadPropertiesResource(
                "system", "org/underworldlabs/jobexftp/system.properties");

        // load the default properties
        SystemProperties.loadPropertiesResource(
                "defaults", "org/underworldlabs/jobexftp/default.properties");

        // make sure the user props dir exists
        SystemResources.buildUserProperties();

        // load the user properties with the defaults set
        Properties defaults = SystemProperties.getProperties("defaults");
        SystemProperties.loadProperties(
                "user", SystemResources.getUserSettingsFilePath(), defaults);

        // set the look and feel
        //loadDefaultLookAndFeel();
        
        // register the icon and image directories
        //IconUtilities.setIconResourcePath(
        //        SystemProperties.getProperty("system", "icons.path"));

        frame = new JFrame("JObexFTP");
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

        ActionBuilder.build(GUIUtilities.getActionMap(),
                GUIUtilities.getInputMap(JComponent.WHEN_IN_FOCUSED_WINDOW),
                Constants.ACTION_CONF_PATH);

        JObexBasePanel panel = new JObexBasePanel();
        JObexController.registerBasePanel(panel);

        Container container = frame.getContentPane();
        container.setLayout(new BorderLayout());
        
        JObexToolBar toolBar = new JObexToolBar();
        container.add(toolBar.getToolBarBasePanel(), BorderLayout.NORTH);

        //container.add(new JObexToolBar(), BorderLayout.NORTH);
        container.add(panel, BorderLayout.CENTER);
        container.add(GUIUtilities.getStatusBarPanel(), BorderLayout.SOUTH);

        frame.setSize(850, 550);
        frame.setVisible(true);
        
    }
    
    /** 
     * Sets the default 'Execute Query' look and feel.
     */
    private void loadDefaultLookAndFeel() {
        try {
            org.underworldlabs.swing.plaf.ShadesOfGrayLookAndFeel metal = 
                    new org.underworldlabs.swing.plaf.ShadesOfGrayLookAndFeel();
            UIManager.setLookAndFeel(metal);
        } catch (UnsupportedLookAndFeelException e) {
            e.printStackTrace();
        } catch (Exception e) {
            e.printStackTrace();
            lookAndFeelError();
            loadCrossPlatformLookAndFeel();
        }
        
    }

    /**
     * Loads the cross-platform look and feel.
     */
    private void loadCrossPlatformLookAndFeel() {
        try {
            UIManager.setLookAndFeel(
                    UIManager.getCrossPlatformLookAndFeelClassName());
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * Simple dialog with generic look and feel error message.
     */
    private void lookAndFeelError() {
        GUIUtilities.displayWarningMessage(
                "The selected look and feel is not " +
                "supported within this environment." +
                "\nThe system will revert to the default look and feel.");
    }

    /**
     * Returns the application frame.
     */
    public static JFrame getApplicationFrame() {
        return frame;
    }
    
    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        new JObexFTP();
    }
    
}



