/*
 * ObexProcessProgressDialog.java
 *
 * Copyright (C) 2007 Takis Diakoumis
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */

package org.underworldlabs.jobexftp;

import java.awt.Container;
import java.awt.Dimension;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JPanel;

import org.underworldlabs.jobexftp.util.GUIUtilities;
import org.underworldlabs.swing.IndeterminateProgressBar;

/**
 * Progress bar dialog with cancel button.
 *
 * @author Takis Diakoumis
 */
public class ObexProcessProgressDialog extends JDialog
                                      implements Runnable,
                                                 ActionListener {
    
    /** the parent controlling process */
    private InterruptibleProcess parent;
    
    /** The progress bar widget */
    private IndeterminateProgressBar progressBar;
    
    /** the text label text */
    private String labelText;
    
    public ObexProcessProgressDialog(InterruptibleProcess parent, 
                                    String title, String labelText) {
        super(GUIUtilities.getApplicationFrame(), title, true);
        this.parent = parent;
        this.labelText = labelText;
        try {
            init();
        }
        catch (Exception e) {
            e.printStackTrace();
        }
    }
    
    public void run() {
        pack();
        setLocation(GUIUtilities.getLocationForDialog(getSize()));
        progressBar.start();
        setVisible(true);
    }
    
    private void init() throws Exception {
        
        progressBar = new IndeterminateProgressBar();
        progressBar.setPreferredSize(new Dimension(260, 18));

        JPanel base = new JPanel(new GridBagLayout());
        
        JButton cancelButton = new JButton("Cancel");
        cancelButton.setPreferredSize(new Dimension(75, 30));
        cancelButton.addActionListener(this);
        
        GridBagConstraints gbc = new GridBagConstraints();
        Insets ins = new Insets(10, 20, 10, 20);
        gbc.insets = ins;
        base.add(new JLabel(labelText), gbc);
        gbc.gridy = 1;
        gbc.insets.top = 0;
        base.add(progressBar, gbc);
        gbc.gridy = 2;
        gbc.weighty = 1.0;
        base.add(cancelButton, gbc);
        
        base.setBorder(BorderFactory.createEtchedBorder());
        
        Container c = this.getContentPane();
        c.setLayout(new GridBagLayout());
        c.add(base, new GridBagConstraints(1, 1, 1, 1, 1.0, 1.0,
                                           GridBagConstraints.SOUTHEAST, 
                                           GridBagConstraints.BOTH,
                                           new Insets(5, 5, 5, 5), 0, 0));
        setResizable(false);
        setDefaultCloseOperation(JDialog.DISPOSE_ON_CLOSE);
    }

    public void actionPerformed(ActionEvent e) {    
        GUIUtilities.outputPlainText("Connection to device cancelled");
        parent.cancel();
        dispose();
    }
    
    public void dispose() {
        if (progressBar != null) {
            progressBar.stop();
            progressBar.cleanup();
        }
        super.dispose();        
    }
    
}



