/*
 * StatusBarPanel.java
 *
 * Copyright (C) 2007 Takis Diakoumis
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */

package org.underworldlabs.jobexftp;

import javax.swing.BorderFactory;
import javax.swing.JLabel;
import org.underworldlabs.swing.AbstractStatusBarPanel;
import org.underworldlabs.swing.IndeterminateProgressBar;

/**
 *
 * @author takisd
 */
public class StatusBarPanel extends AbstractStatusBarPanel {
   
    /** the progress bar */
    private IndeterminateProgressBar progressBar;
    
    /** the status bar panel fixed height */
    private static final int HEIGHT = 20;

    /** 
     * Creates a new instance with the default height.
     */
    public StatusBarPanel() {
        super(HEIGHT);    
        try {
            jbInit();
        } catch(Exception e) {
            e.printStackTrace();
        }
    }
    
    /** <p>Initialises the state of this instance. */
    private void jbInit() throws Exception {
        setBorder(BorderFactory.createEmptyBorder(2,3,3,4));
        progressBar = new IndeterminateProgressBar(false);
        addLabel(0, 110, true);
        addLabel(1, 50, true);
        addLabel(2, 80, false);
        addComponent(progressBar, 3, 100, false);

        // set the insert mode label to center alignment
        getLabel(2).setHorizontalAlignment(JLabel.CENTER);        
    }

    public void setThirdLabelText(String text) {
        setLabelText(2, text);
    }
    
    public void setSecondLabelText(String text) {
        setLabelText(1, text);
    }
    
    public void setFirstLabelText(final String text) {
        setLabelText(0, text);
    }
    
    public void resetStatusBar() {
        String EMPTY = "";
        setLabelText(0, EMPTY);
        setLabelText(1, EMPTY);
        setLabelText(2, EMPTY);
    }
    
    public void setFourthLabelText(String text) {
        setLabelText(3, text);
    }

    /**
     * Indicates that a process has begun and kicks off the
     * status bar's indeterminate progress bar.
     */
    public void startProcessing() {
        progressBar.start();
    }

    /**
     * Indicates that a process has finished and stops the
     * status bar's indeterminate progress bar.
     */
    public void stopProcessing() {
        progressBar.stop();
    }

}



