/*
 * BaseObexCommand.java
 *
 * Copyright (C) 2007 Takis Diakoumis
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */

package org.underworldlabs.jobexftp.actions;

import java.awt.event.ActionEvent;
import org.underworldlabs.jobexftp.JObexController;
import org.underworldlabs.jobexftp.util.GUIUtilities;
import org.underworldlabs.swing.actions.BaseCommand;

/**
 * Base action class for obex commands.
 *
 * @author Takis Diakoumis
 */
public abstract class BaseObexCommand implements BaseCommand {
    
    public abstract void execute(ActionEvent e);
    
    protected boolean isConnected() {
        if (!JObexController.isConnected()) {
            GUIUtilities.displayErrorMessage(
                "Not Connected.\nPlease establish a connection to a device to continue.");
            return false;
        }
        return true;
    }

    /**
     * Handles the specified exception by displaying an error 
     * dialog with the exception message details.
     */
    protected void handleException(Throwable e) {
        e.printStackTrace();
        GUIUtilities.displayErrorMessage(
                "Error in obex command execution:\n" + e.getMessage());
    }

}



