/*
 * DeleteFilesCommand.java
 *
 * Copyright (C) 2007 Takis Diakoumis
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */

package org.underworldlabs.jobexftp.actions;

import java.awt.event.ActionEvent;
import java.util.List;
import javax.swing.JOptionPane;
import org.underworldlabs.jobexftp.JObexController;
import org.underworldlabs.jobexftp.ObexProcessException;
import org.underworldlabs.jobexftp.obexobjects.ObexObject;
import org.underworldlabs.jobexftp.util.GUIUtilities;
import org.underworldlabs.swing.util.SwingWorker;

/**
 * Defines the execution for a delete file process.
 *
 * @author Takis Diakoumis
 */
public class DeleteFilesCommand extends ObexProcessCommand {
    
    public void execute(ActionEvent e) {
        
        if (!isConnected()) {
            return;
        }

        List<ObexObject> objects =  JObexController.getSelectedObjects();
        if (objects == null || objects.size() == 0) {
            return;
        }

        final String[] _files = new String[objects.size()];
        for (int i = 0; i < _files.length; i++) {
            _files[i] = objects.get(i).getPath();
        }
        
        int result = GUIUtilities.displayConfirmDialog(
                "Are you sure you want to delete the selected file(s)");
        
        if (result != JOptionPane.YES_OPTION) {
            return;
        }
        
        worker = new SwingWorker() {
            public Object construct() {
                GUIUtilities.showWaitCursor();
                doWork(_files);
                return "done";
            }
            public void finished() {
                GUIUtilities.showNormalCursor();
            }
        };
        worker.start();
    }

    private void doWork(String[] files) {
        try {
            JObexController.delete(files);
        }
        catch (ObexProcessException e) {
            handleException(e);
        }
    }

}



