/*
 * DownloadFilesAction.java
 *
 * Copyright (C) 2007 Takis Diakoumis
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */

package org.underworldlabs.jobexftp.actions;

import java.awt.event.ActionEvent;
import java.util.List;
import javax.swing.JFileChooser;
import org.underworldlabs.jobexftp.ObexProcessProgressDialog;
import org.underworldlabs.jobexftp.JObexController;
import org.underworldlabs.jobexftp.ObexProcessException;
import org.underworldlabs.jobexftp.obexobjects.ObexFile;
import org.underworldlabs.jobexftp.util.GUIUtilities;
import org.underworldlabs.swing.util.SwingWorker;
import org.underworldlabs.util.MiscUtils;

/**
 * Defines the execution for a file download process.
 *
 * @author Takis Diakoumis
 */
public class DownloadFilesAction extends ObexProcessCommand { 

    /** progress dialog */
    private ObexProcessProgressDialog progressDialog;

    public void execute(ActionEvent e) {
        
        if (!isConnected()) {
            return;
        }
        
        List<ObexFile> files = JObexController.getSelectedFiles();
        if (files == null || files.size() == 0) {
            GUIUtilities.displayErrorMessage(
                    "Invalid file selection.\nPlease select a valid file for download");
            return;
        }
        
        final String[] _files = new String[files.size()];
        for (int i = 0; i < _files.length; i++) {
            _files[i] = files.get(i).getPath();
        }
        
        String lastPath = JObexController.getLastPathLocation();
        JFileChooser fileChooser = new JFileChooser(lastPath);
        fileChooser.setDialogTitle("File Download");
        fileChooser.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);

        int result = fileChooser.showDialog(GUIUtilities.getApplicationFrame(), "Save");
        if (result != JFileChooser.CANCEL_OPTION) {
            final String toPath = fileChooser.getSelectedFile().getAbsolutePath();

            // store the last selected path
            JObexController.setLastPathLocation(toPath);
            
            if (MiscUtils.isNull(toPath)) {
                GUIUtilities.displayErrorMessage("Invalid download location selected");
                return;
            }
            
            worker = new SwingWorker() {
                public Object construct() {
                    GUIUtilities.showWaitCursor();
                    doWork(_files, toPath);
                    return "done";
                }
                public void finished() {
                    if (progressDialog != null) {
                        progressDialog.dispose();
                    }
                    GUIUtilities.showNormalCursor();
                }
            };

            progressDialog = new ObexProcessProgressDialog(
                    this, "Downloading...", "Downloading selected files...");
            worker.start();
            progressDialog.run();
        }

    }

    private void doWork(String[] files, String toPath) {
        try {
            JObexController.download(files, toPath);
        }
        catch (ObexProcessException e) {
            handleException(e);
        }
    }

}



