/*
 * MkdirAction.java
 *
 * Copyright (C) 2007 Takis Diakoumis
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */

package org.underworldlabs.jobexftp.actions;

import java.awt.event.ActionEvent;
import org.underworldlabs.jobexftp.JObexController;
import org.underworldlabs.jobexftp.ObexProcessException;
import org.underworldlabs.jobexftp.ObexProcessProgressDialog;
import org.underworldlabs.jobexftp.util.GUIUtilities;
import org.underworldlabs.swing.util.SwingWorker;
import org.underworldlabs.util.MiscUtils;

/**
 * Defines the execution for a mkdir process.
 *
 * @author Takis Diakoumis
 */
public class MkdirAction extends ObexProcessCommand {
    
    public void execute(ActionEvent e) {
        
        if (!isConnected()) {
            return;
        }

        final String parentFolder = JObexController.getSelectedFolder();
        if (MiscUtils.isNull(parentFolder)) {
            GUIUtilities.displayErrorMessage(
                    "Please select the parent folder from the folder tree.");
            return;
        }

        worker = new SwingWorker() {
            public Object construct() {
                GUIUtilities.showWaitCursor();
                doWork(parentFolder);
                return "done";
            }
            public void finished() {
                GUIUtilities.showNormalCursor();
            }
        };
        worker.start();
    }

    private void doWork(String parentFolder) {
        try {
            String name = GUIUtilities.displayInputMessage("New Folder", 
                    "Enter the name of the new folder");

            if (!MiscUtils.isNull(name)) {
                boolean created = JObexController.mkdir(parentFolder, name);

                if (!created) {
                    GUIUtilities.displayErrorMessage(
                            "Failed to create the folder specified.");
                }
            }

        }
        catch (ObexProcessException e) {
            handleException(e);
        }
    }

}



