/*
 * UploadFileAction.java
 *
 * Copyright (C) 2007 Takis Diakoumis
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */

package org.underworldlabs.jobexftp.actions;

import java.awt.event.ActionEvent;
import java.io.File;
import javax.swing.JFileChooser;
import org.underworldlabs.jobexftp.JObexController;
import org.underworldlabs.jobexftp.ObexProcessException;
import org.underworldlabs.jobexftp.ObexProcessProgressDialog;
import org.underworldlabs.jobexftp.util.GUIUtilities;
import org.underworldlabs.swing.util.SwingWorker;

/**
 * Defines the execution for a file upload process.
 *
 * @author Takis Diakoumis
 */
public class UploadFileAction extends ObexProcessCommand { 

    /** progress dialog */
    private ObexProcessProgressDialog progressDialog;

    public void execute(ActionEvent e) {
        
        if (!isConnected()) {
            return;
        }
        String lastPath = JObexController.getLastPathLocation();
        JFileChooser fileChooser = new JFileChooser(lastPath);
        fileChooser.setDialogTitle("File Upload");
        fileChooser.setFileSelectionMode(JFileChooser.FILES_ONLY);

        int result = fileChooser.showDialog(GUIUtilities.getApplicationFrame(), "Open");
        if (result != JFileChooser.CANCEL_OPTION) {
            File file = fileChooser.getSelectedFile();
            final String name = file.getAbsolutePath();
            final String parent = JObexController.getSelectedFolder();

            // store the last selected path
            JObexController.setLastPathLocation(file.getParent());

            worker = new SwingWorker() {
                public Object construct() {
                    GUIUtilities.showWaitCursor();
                    doWork(name, parent);
                    return "done";
                }
                public void finished() {
                    if (progressDialog != null) {
                        progressDialog.dispose();
                    }
                    GUIUtilities.showNormalCursor();
                }
            };

            progressDialog = new ObexProcessProgressDialog(
                    this, "Uploading...", "Uploading selected files...");
            worker.start();
            progressDialog.run();
        }

    }

    private void doWork(String name, String parent) {
        try {
            JObexController.upload(name, parent);
        } 
        catch (ObexProcessException e) {
            handleException(e);
        }
    }
    
}



