/*
 * ViewFileCommand.java
 *
 * Copyright (C) 2007 Takis Diakoumis
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */

package org.underworldlabs.jobexftp.actions;

import java.awt.event.ActionEvent;
import java.io.File;
import java.util.List;
import org.underworldlabs.jobexftp.ImageFileViewer;
import org.underworldlabs.jobexftp.JObexController;
import org.underworldlabs.jobexftp.ObexProcessException;
import org.underworldlabs.jobexftp.obexobjects.ObexFile;
import org.underworldlabs.jobexftp.util.GUIUtilities;
import org.underworldlabs.swing.util.SwingWorker;

/**
 * Executes the command to open/view a file.
 *
 * @author Takis Diakoumis
 */
public class ViewFileCommand extends ObexProcessCommand {
    
    public void execute(ActionEvent e) {
        
        if (!isConnected()) {
            return;
        }

        List<ObexFile> files = JObexController.getSelectedFiles();
        if (files == null || files.size() == 0) {
            return;
        }

        /*
        String[] files = JObexController.getSelectedFiles();
        if (files == null || files.length == 0) {
            return;
        }
        */

        // use the first file only
        //final String file = files[0];
        final String file = files.get(0).getPath();
        
        // retrieve the temp dir path
        final String tempPath = System.getProperty("java.io.tmpdir");

        worker = new SwingWorker() {
            public Object construct() {
                GUIUtilities.startProcessing();
                GUIUtilities.showWaitCursor();
                doWork(file, tempPath);
                return "done";
            }
            public void finished() {
                GUIUtilities.showNormalCursor();
                GUIUtilities.stopProcessing();
                viewFile(file, tempPath);
            }
        };
        worker.start();
    }

    private void viewFile(String path, String toPath) {
        StringBuffer sb = new StringBuffer();
        sb.append(toPath);
        sb.append(System.getProperty("file.separator"));
        sb.append(path.substring(path.lastIndexOf("/") + 1));

        // make sure it exists
        File file = new File(sb.toString());
        if (!file.exists()) {
            GUIUtilities.displayErrorMessage(
                    "An error occurred during the download process." +
                    "\nImage not available for viewing.");
            return;
        }
        
        new ImageFileViewer(file.getAbsolutePath());
    }
    
    private void doWork(String file, String toPath) {
        try {
            JObexController.download(new String[]{file}, toPath);
        }
        catch (ObexProcessException e) {
            handleException(e);
        }
    }

}



